# Table of Contents

- [tech-stack-discovery-from-sboms](<./tech-stack-discovery-from-sboms.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Tech Stack Discovery from SBOMs](<./Tech-Stack-Discovery-from-SBOMs.md>)
  - [Introduction](<./Tech-Stack-Discovery-from-SBOMs/Introduction.md>)
  - [Prerequisites](<./Tech-Stack-Discovery-from-SBOMs/Prerequisites.md>)
  - [Permissions](<./Tech-Stack-Discovery-from-SBOMs/Permissions.md>)
  - [Discovering and Creating IT Components](<./Tech-Stack-Discovery-from-SBOMs/Discovering-and-Creating-IT-Components.md>)
  - [Viewing Tech Stacks](<./Tech-Stack-Discovery-from-SBOMs/Viewing-Tech-Stacks.md>)
  - [Adding Custom Tech Stacks Manually](<./Tech-Stack-Discovery-from-SBOMs/Adding-Custom-Tech-Stacks-Manually.md>)
  - [Technical Details](<./Tech-Stack-Discovery-from-SBOMs/Technical-Details.md>)
  - [Was this page helpful?](<./Tech-Stack-Discovery-from-SBOMs/Was-this-page-helpful.md>)
